@@ -192,7 +192,7 @@ empathy_contact_add_menu_item_new (EmpathyContact *contact)
 		return NULL;
 	}
 
-	item = gtk_image_menu_item_new_with_mnemonic (_("_Add Contact..."));
+	item = gtk_image_menu_item_new_with_mnemonic (_("_Add Contact…"));
 	image = gtk_image_new_from_icon_name (GTK_STOCK_ADD,
 					      GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -483,10 +483,7 @@ static void
 room_sub_menu_activate_cb (GtkWidget *item,
 			   RoomSubMenuData *data)
 {
-	TpHandle handle;
-	GArray handles = {(gchar *) &handle, 1};
 	EmpathyTpChat *chat;
-	TpChannel *channel;
 
 	chat = empathy_chatroom_get_tp_chat (data->chatroom);
 	if (chat == NULL) {
@@ -495,10 +492,8 @@ room_sub_menu_activate_cb (GtkWidget *item,
 	}
 
 	/* send invitation */
-	handle = empathy_contact_get_handle (data->contact);
-	channel = empathy_tp_chat_get_channel (chat);
-	tp_cli_channel_interface_group_call_add_members (channel, -1, &handles,
-		_("Inviting to this room"), NULL, NULL, NULL, NULL);
+	empathy_contact_list_add (EMPATHY_CONTACT_LIST (chat), data->contact,
+		_("Inviting you to this room"));
 }
 
 static GtkWidget *
@@ -529,7 +524,7 @@ empathy_contact_invite_menu_item_new (EmpathyContact *contact)
 
 	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), NULL);
 
-	item = gtk_image_menu_item_new_with_mnemonic (_("_Invite to chatroom"));
+	item = gtk_image_menu_item_new_with_mnemonic (_("_Invite to chat room"));
 	image = gtk_image_new_from_icon_name (EMPATHY_IMAGE_GROUP_MESSAGE,
 					      GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
