@@ -706,26 +706,31 @@ theme_adium_clear (EmpathyChatView *view)
 static gboolean
 theme_adium_find_previous (EmpathyChatView *view,
 			   const gchar     *search_criteria,
-			   gboolean         new_search)
+			   gboolean         new_search,
+			   gboolean         match_case)
 {
+	/* FIXME: Doesn't respect new_search */
 	return webkit_web_view_search_text (WEBKIT_WEB_VIEW (view),
-					    search_criteria, FALSE,
+					    search_criteria, match_case,
 					    FALSE, TRUE);
 }
 
 static gboolean
 theme_adium_find_next (EmpathyChatView *view,
 		       const gchar     *search_criteria,
-		       gboolean         new_search)
+		       gboolean         new_search,
+		       gboolean         match_case)
 {
+	/* FIXME: Doesn't respect new_search */
 	return webkit_web_view_search_text (WEBKIT_WEB_VIEW (view),
-					    search_criteria, FALSE,
+					    search_criteria, match_case,
 					    TRUE, TRUE);
 }
 
 static void
 theme_adium_find_abilities (EmpathyChatView *view,
 			    const gchar    *search_criteria,
+                            gboolean        match_case,
 			    gboolean       *can_do_previous,
 			    gboolean       *can_do_next)
 {
@@ -739,11 +744,12 @@ theme_adium_find_abilities (EmpathyChatView *view,
 
 static void
 theme_adium_highlight (EmpathyChatView *view,
-		       const gchar     *text)
+		       const gchar     *text,
+		       gboolean         match_case)
 {
 	webkit_web_view_unmark_text_matches (WEBKIT_WEB_VIEW (view));
 	webkit_web_view_mark_text_matches (WEBKIT_WEB_VIEW (view),
-					   text, FALSE, 0);
+					   text, match_case, 0);
 	webkit_web_view_set_highlight_text_matches (WEBKIT_WEB_VIEW (view),
 						    TRUE);
 }
