@@ -30,11 +30,11 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
+#include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/interfaces.h>
 
 #include "empathy-tp-chat.h"
 #include "empathy-chatroom-manager.h"
-#include "empathy-account-manager.h"
 #include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
@@ -51,9 +51,11 @@ typedef struct
 {
   GList *chatrooms;
   gchar *file;
-  EmpathyAccountManager *account_manager;
+  TpAccountManager *account_manager;
+
   /* source id of the autosave timer */
   gint save_timer_id;
+  gboolean ready;
 } EmpathyChatroomManagerPriv;
 
 enum {
@@ -68,6 +70,7 @@ static guint signals[LAST_SIGNAL];
 enum
 {
   PROP_FILE = 1,
+  PROP_READY,
   LAST_PROPERTY
 };
 
@@ -87,8 +90,8 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 
 	priv = GET_PRIV (manager);
 
-	doc = xmlNewDoc ("1.0");
-	root = xmlNewNode (NULL, "chatrooms");
+	doc = xmlNewDoc ((const xmlChar *) "1.0");
+	root = xmlNewNode (NULL, (const xmlChar *) "chatrooms");
 	xmlDocSetRootElement (doc, root);
 
 	for (l = priv->chatrooms; l; l = l->next) {
@@ -102,15 +105,19 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 			continue;
 		}
 
-		account_id = empathy_account_get_unique_name (
+                account_id = tp_proxy_get_object_path (
 		  empathy_chatroom_get_account (chatroom));
 
-		node = xmlNewChild (root, NULL, "chatroom", NULL);
-		xmlNewTextChild (node, NULL, "name", empathy_chatroom_get_name (chatroom));
-		xmlNewTextChild (node, NULL, "room", empathy_chatroom_get_room (chatroom));
-		xmlNewTextChild (node, NULL, "account", account_id);
-		xmlNewTextChild (node, NULL, "auto_connect",
-			empathy_chatroom_get_auto_connect (chatroom) ? "yes" : "no");
+		node = xmlNewChild (root, NULL, (const xmlChar *) "chatroom", NULL);
+		xmlNewTextChild (node, NULL, (const xmlChar *) "name",
+			(const xmlChar *) empathy_chatroom_get_name (chatroom));
+		xmlNewTextChild (node, NULL, (const xmlChar *) "room",
+			(const xmlChar *) empathy_chatroom_get_name (chatroom));
+		xmlNewTextChild (node, NULL, (const xmlChar *) "account",
+			(const xmlChar *) account_id);
+		xmlNewTextChild (node, NULL, (const xmlChar *) "auto_connect",
+			empathy_chatroom_get_auto_connect (chatroom) ?
+			(const xmlChar *) "yes" : (const xmlChar *) "no");
 	}
 
 	/* Make sure the XML is indented properly */
@@ -120,7 +127,6 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 	xmlSaveFormatFileEnc (priv->file, doc, "utf-8", 1);
 	xmlFreeDoc (doc);
 
-	xmlCleanupParser ();
 	xmlMemoryDump ();
 
 	return TRUE;
@@ -177,7 +183,7 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 {
 	EmpathyChatroomManagerPriv *priv;
 	EmpathyChatroom            *chatroom;
-	EmpathyAccount             *account;
+	TpAccount                  *account;
 	xmlNodePtr                 child;
 	gchar                     *str;
 	gchar                     *name;
@@ -223,7 +229,7 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 		xmlFree (str);
 	}
 
-	account = empathy_account_manager_get_account (priv->account_manager,
+	account = tp_account_manager_ensure_account (priv->account_manager,
 		account_id);
 	if (!account) {
 		g_free (name);
@@ -303,6 +309,9 @@ chatroom_manager_get_all (EmpathyChatroomManager *manager)
 		return FALSE;
 	}
 
+        priv->ready = TRUE;
+        g_object_notify (G_OBJECT (manager), "ready");
+
 	return TRUE;
 }
 
@@ -320,6 +329,9 @@ empathy_chatroom_manager_get_property (GObject *object,
       case PROP_FILE:
         g_value_set_string (value, priv->file);
         break;
+      case PROP_READY:
+        g_value_set_boolean (value, priv->ready);
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -382,6 +394,25 @@ chatroom_manager_finalize (GObject *object)
   (G_OBJECT_CLASS (empathy_chatroom_manager_parent_class)->finalize) (object);
 }
 
+static void
+account_manager_ready_cb (GObject *source_object,
+                          GAsyncResult *result,
+                          gpointer user_data)
+{
+  EmpathyChatroomManager *self = EMPATHY_CHATROOM_MANAGER (user_data);
+  TpAccountManager *manager = TP_ACCOUNT_MANAGER (source_object);
+  GError *error = NULL;
+
+  if (!tp_account_manager_prepare_finish (manager, result, &error))
+    {
+      DEBUG ("Failed to prepare account manager: %s", error->message);
+      g_error_free (error);
+      return;
+    }
+
+  chatroom_manager_get_all (self);
+}
+
 static GObject *
 empathy_chatroom_manager_constructor (GType type,
                                       guint n_props,
@@ -401,10 +432,15 @@ empathy_chatroom_manager_constructor (GType type,
   self = EMPATHY_CHATROOM_MANAGER (obj);
   priv = GET_PRIV (self);
 
+  priv->ready = FALSE;
+
   chatroom_manager_singleton = self;
   g_object_add_weak_pointer (obj, (gpointer) &chatroom_manager_singleton);
 
-  priv->account_manager = empathy_account_manager_dup_singleton ();
+  priv->account_manager = tp_account_manager_dup ();
+
+  tp_account_manager_prepare_async (priv->account_manager, NULL,
+      account_manager_ready_cb, self);
 
   if (priv->file == NULL)
     {
@@ -419,7 +455,6 @@ empathy_chatroom_manager_constructor (GType type,
       g_free (dir);
     }
 
-  chatroom_manager_get_all (self);
   return obj;
 }
 
@@ -446,6 +481,14 @@ empathy_chatroom_manager_class_init (EmpathyChatroomManagerClass *klass)
       G_PARAM_STATIC_BLURB);
   g_object_class_install_property (object_class, PROP_FILE, param_spec);
 
+  param_spec = g_param_spec_boolean (
+      "ready",
+      "whether the manager is ready yet",
+      "whether the manager is ready yet",
+      FALSE,
+      G_PARAM_READABLE);
+  g_object_class_install_property (object_class, PROP_READY, param_spec);
+
   signals[CHATROOM_ADDED] = g_signal_new ("chatroom-added",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
@@ -560,7 +603,7 @@ empathy_chatroom_manager_remove (EmpathyChatroomManager *manager,
 
 EmpathyChatroom *
 empathy_chatroom_manager_find (EmpathyChatroomManager *manager,
-                               EmpathyAccount *account,
+                               TpAccount *account,
                                const gchar *room)
 {
 	EmpathyChatroomManagerPriv *priv;
@@ -573,7 +616,7 @@ empathy_chatroom_manager_find (EmpathyChatroomManager *manager,
 
 	for (l = priv->chatrooms; l; l = l->next) {
 		EmpathyChatroom *chatroom;
-		EmpathyAccount *this_account;
+		TpAccount *this_account;
 		const gchar    *this_room;
 
 		chatroom = l->data;
@@ -591,7 +634,7 @@ empathy_chatroom_manager_find (EmpathyChatroomManager *manager,
 
 GList *
 empathy_chatroom_manager_get_chatrooms (EmpathyChatroomManager *manager,
-				       EmpathyAccount *account)
+				       TpAccount *account)
 {
 	EmpathyChatroomManagerPriv *priv;
 	GList                     *chatrooms, *l;
@@ -620,7 +663,7 @@ empathy_chatroom_manager_get_chatrooms (EmpathyChatroomManager *manager,
 
 guint
 empathy_chatroom_manager_get_count (EmpathyChatroomManager *manager,
-				   EmpathyAccount *account)
+				   TpAccount *account)
 {
 	EmpathyChatroomManagerPriv *priv;
 	GList                     *l;
@@ -679,14 +722,13 @@ static void
 chatroom_manager_observe_channel_cb (EmpathyDispatcher *dispatcher,
   EmpathyDispatchOperation *operation, gpointer manager)
 {
-  EmpathyChatroomManagerPriv *priv = GET_PRIV (manager);
   EmpathyChatroom *chatroom;
   TpChannel *channel;
   EmpathyTpChat *chat;
   const gchar *roomname;
   GQuark channel_type;
   TpHandleType handle_type;
-  EmpathyAccount *account;
+  TpAccount *account;
   TpConnection *connection;
 
   channel_type = empathy_dispatch_operation_get_channel_type_id (operation);
@@ -704,8 +746,7 @@ chatroom_manager_observe_channel_cb (EmpathyDispatcher *dispatcher,
   chat = EMPATHY_TP_CHAT (
     empathy_dispatch_operation_get_channel_wrapper (operation));
   connection = empathy_tp_chat_get_connection (chat);
-  account = empathy_account_manager_get_account_for_connection (
-      priv->account_manager, connection);
+  account = empathy_get_account_for_connection (connection);
 
   roomname = empathy_tp_chat_get_id (chat);
 
