@@ -144,6 +144,10 @@ contact_manager_status_changed_cb (TpAccount *account,
 	EmpathyTpContactList      *list;
 	TpConnection              *connection;
 
+	if (new_status == TP_CONNECTION_STATUS_DISCONNECTED)
+		/* No point to start tracking a connection which is about to die */
+		return;
+
 	connection = tp_account_get_connection (account);
 
 	if (connection == NULL || g_hash_table_lookup (priv->lists, connection)) {
@@ -171,6 +175,19 @@ contact_manager_status_changed_cb (TpAccount *account,
 			  self);
 }
 
+static void
+contact_manager_validity_changed_cb (TpAccountManager *account_manager,
+				     TpAccount *account,
+				     gboolean valid,
+				     EmpathyContactManager *manager)
+{
+	if (valid) {
+		empathy_signal_connect_weak (account, "status-changed",
+			    G_CALLBACK (contact_manager_status_changed_cb),
+			    G_OBJECT (manager));
+	}
+}
+
 static void
 contact_manager_finalize (GObject *object)
 {
@@ -268,6 +285,10 @@ account_manager_prepared_cb (GObject *source_object,
 		    G_OBJECT (manager));
 	}
 	g_list_free (accounts);
+
+	empathy_signal_connect_weak (account_manager, "account-validity-changed",
+			     G_CALLBACK (contact_manager_validity_changed_cb),
+			     G_OBJECT (manager));
 }
 
 static void
