@@ -51,6 +51,8 @@ static GDebugKey keys[] = {
   { "Other", EMPATHY_DEBUG_OTHER },
   { "Connectivity", EMPATHY_DEBUG_CONNECTIVITY },
   { "ImportMc4Accounts", EMPATHY_DEBUG_IMPORT_MC4_ACCOUNTS },
+  { "Tests", EMPATHY_DEBUG_TESTS },
+  { "Voip", EMPATHY_DEBUG_VOIP },
   { 0, }
 };
 
