@@ -35,7 +35,6 @@
 #include <clutter-gtk/clutter-gtk.h>
 #endif
 
-#include <libebook/e-book.h>
 #include <libnotify/notify.h>
 
 #include <telepathy-glib/account-manager.h>
@@ -71,6 +70,7 @@
 #include "empathy-chat-window.h"
 #include "empathy-ft-manager.h"
 #include "empathy-import-mc4-accounts.h"
+#include "empathy-auto-salut-account-helper.h"
 
 #include "extensions/extensions.h"
 
@@ -152,75 +152,6 @@ dispatch_cb (EmpathyDispatcher *dispatcher,
     }
 }
 
-/* Salut account creation. The TpAccountManager first argument
- * must already be prepared when calling this function. */
-static gboolean
-should_create_salut_account (TpAccountManager *manager)
-{
-  gboolean salut_created = FALSE;
-  GList *accounts, *l;
-
-  /* Check if we already created a salut account */
-  empathy_conf_get_bool (empathy_conf_get (),
-      EMPATHY_PREFS_SALUT_ACCOUNT_CREATED,
-      &salut_created);
-
-  if (salut_created)
-    {
-      DEBUG ("Gconf says we already created a salut account once");
-      return FALSE;
-    }
-
-  accounts = tp_account_manager_get_valid_accounts (manager);
-
-  for (l = accounts; l != NULL;  l = g_list_next (l))
-    {
-      TpAccount *account = TP_ACCOUNT (l->data);
-
-      if (!tp_strdiff (tp_account_get_protocol (account), "local-xmpp"))
-        {
-          salut_created = TRUE;
-          break;
-        }
-    }
-
-  g_list_free (accounts);
-
-  if (salut_created)
-    {
-      DEBUG ("Existing salut account already exists, flagging so in gconf");
-      empathy_conf_set_bool (empathy_conf_get (),
-          EMPATHY_PREFS_SALUT_ACCOUNT_CREATED,
-          TRUE);
-    }
-
-  return !salut_created;
-}
-
-static void
-salut_account_created (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  EmpathyAccountSettings *settings = EMPATHY_ACCOUNT_SETTINGS (source);
-  TpAccount *account;
-  GError *error = NULL;
-
-  if (!empathy_account_settings_apply_finish (settings, result, &error))
-    {
-      DEBUG ("Failed to create salut account: %s", error->message);
-      g_error_free (error);
-      return;
-    }
-
-  account = empathy_account_settings_get_account (settings);
-
-  tp_account_set_enabled_async (account, TRUE, NULL, NULL);
-  empathy_conf_set_bool (empathy_conf_get (),
-      EMPATHY_PREFS_SALUT_ACCOUNT_CREATED,
-      TRUE);
-}
-
 static void
 use_conn_notify_cb (EmpathyConf *conf,
     const gchar *key,
@@ -235,117 +166,6 @@ use_conn_notify_cb (EmpathyConf *conf,
     }
 }
 
-static void
-create_salut_account_am_ready_cb (GObject *source_object,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  TpAccountManager *account_manager = TP_ACCOUNT_MANAGER (source_object);
-  EmpathyConnectionManagers *managers = user_data;
-  EmpathyAccountSettings  *settings;
-  TpConnectionManager *manager;
-  const TpConnectionManagerProtocol *protocol;
-  EBook      *book;
-  EContact   *contact;
-  gchar      *nickname = NULL;
-  gchar      *first_name = NULL;
-  gchar      *last_name = NULL;
-  gchar      *email = NULL;
-  gchar      *jid = NULL;
-  GError     *error = NULL;
-
-  if (!tp_account_manager_prepare_finish (account_manager, result, &error))
-    {
-      DEBUG ("Failed to prepare account manager: %s", error->message);
-      g_error_free (error);
-      goto out;
-    }
-
-  if (!should_create_salut_account (account_manager))
-    goto out;
-
-  manager = empathy_connection_managers_get_cm (managers, "salut");
-  if (manager == NULL)
-    {
-      DEBUG ("Salut not installed, not making a salut account");
-      goto out;
-    }
-
-  protocol = tp_connection_manager_get_protocol (manager, "local-xmpp");
-  if (protocol == NULL)
-    {
-      DEBUG ("Salut doesn't support local-xmpp!!");
-      goto out;
-    }
-
-  DEBUG ("Trying to add a salut account...");
-
-  /* Get self EContact from EDS */
-  if (!e_book_get_self (&contact, &book, &error))
-    {
-      DEBUG ("Failed to get self econtact: %s",
-          error ? error->message : "No error given");
-      g_clear_error (&error);
-      goto out;
-    }
-
-  settings = empathy_account_settings_new ("salut", "local-xmpp",
-      _("People nearby"));
-
-  nickname = e_contact_get (contact, E_CONTACT_NICKNAME);
-  first_name = e_contact_get (contact, E_CONTACT_GIVEN_NAME);
-  last_name = e_contact_get (contact, E_CONTACT_FAMILY_NAME);
-  email = e_contact_get (contact, E_CONTACT_EMAIL_1);
-  jid = e_contact_get (contact, E_CONTACT_IM_JABBER_HOME_1);
-
-  if (!tp_strdiff (nickname, "nickname"))
-    {
-      g_free (nickname);
-      nickname = NULL;
-    }
-
-  DEBUG ("Salut account created:\nnickname=%s\nfirst-name=%s\n"
-     "last-name=%s\nemail=%s\njid=%s\n",
-     nickname, first_name, last_name, email, jid);
-
-  empathy_account_settings_set_string (settings,
-      "nickname", nickname ? nickname : "");
-  empathy_account_settings_set_string (settings,
-      "first-name", first_name ? first_name : "");
-  empathy_account_settings_set_string (settings,
-      "last-name", last_name ? last_name : "");
-  empathy_account_settings_set_string (settings, "email", email ? email : "");
-  empathy_account_settings_set_string (settings, "jid", jid ? jid : "");
-
-  empathy_account_settings_apply_async (settings,
-      salut_account_created, NULL);
-
-  g_free (nickname);
-  g_free (first_name);
-  g_free (last_name);
-  g_free (email);
-  g_free (jid);
-  g_object_unref (settings);
-  g_object_unref (contact);
-  g_object_unref (book);
-
- out:
-  g_object_unref (managers);
-}
-
-static void
-create_salut_account_if_needed (EmpathyConnectionManagers *managers)
-{
-  TpAccountManager *manager;
-
-  manager = tp_account_manager_dup ();
-
-  tp_account_manager_prepare_async (manager, NULL,
-      create_salut_account_am_ready_cb, g_object_ref (managers));
-
-  g_object_unref (manager);
-}
-
 static gboolean
 has_non_salut_accounts (TpAccountManager *manager)
 {
@@ -368,40 +188,84 @@ has_non_salut_accounts (TpAccountManager *manager)
   return ret;
 }
 
+/* Try to import accounts from MC4 and returns TRUE if we should display the
+ * accounts assistant. */
+static gboolean
+should_show_account_assistant (TpAccountManager *account_mgr,
+    EmpathyConnectionManagers *cm_mgr)
+{
+  g_return_val_if_fail (tp_account_manager_is_prepared (account_mgr,
+      TP_ACCOUNT_MANAGER_FEATURE_CORE), FALSE);
+  g_return_val_if_fail (empathy_connection_managers_is_ready (cm_mgr), FALSE);
+
+  if (empathy_import_mc4_has_imported ())
+    return FALSE;
+
+  if (empathy_import_mc4_accounts (cm_mgr))
+    return FALSE;
+
+  if (start_hidden)
+    return FALSE;
+
+  if (has_non_salut_accounts (account_mgr))
+    return FALSE;
+
+  if (!should_create_salut_account (account_mgr))
+    return FALSE;
+
+  return TRUE;
+}
+
+static void
+connection_managers_prepare_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  EmpathyConnectionManagers *cm_mgr = EMPATHY_CONNECTION_MANAGERS (source);
+  TpAccountManager *account_mgr = user_data;
+
+  if (!empathy_connection_managers_prepare_finish (cm_mgr, result, NULL))
+    goto out;
+
+  if (should_show_account_assistant (account_mgr, cm_mgr))
+    empathy_account_assistant_show (GTK_WINDOW (empathy_main_window_get ()),
+          cm_mgr);
+
+out:
+  g_object_unref (cm_mgr);
+  g_object_unref (account_mgr);
+}
+
+static void
+account_manager_ready_for_show_assistant (GObject *source_object,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  TpAccountManager *account_mgr = TP_ACCOUNT_MANAGER (source_object);
+  GError *error = NULL;
+  EmpathyConnectionManagers *cm_mgr;
+
+  if (!tp_account_manager_prepare_finish (account_mgr, result, &error))
+    {
+      DEBUG ("Failed to prepare account manager: %s", error->message);
+      g_error_free (error);
+      g_object_unref (account_mgr);
+      return;
+    }
+
+  cm_mgr = empathy_connection_managers_dup_singleton ();
+
+  empathy_connection_managers_prepare_async (cm_mgr,
+      connection_managers_prepare_cb, account_mgr);
+}
+
 static void
 maybe_show_account_assistant (void)
 {
-  TpAccountManager *manager;
-  manager = tp_account_manager_dup ();
+  TpAccountManager *account_mgr = tp_account_manager_dup ();
 
-  if (!has_non_salut_accounts (manager))
-    empathy_account_assistant_show (GTK_WINDOW (empathy_main_window_get ()));
-
-  g_object_unref (manager);
-}
-
-static gboolean
-check_connection_managers_ready (EmpathyConnectionManagers *managers)
-{
-  if (empathy_connection_managers_is_ready (managers))
-    {
-      if (!empathy_import_mc4_accounts (managers) && !start_hidden)
-        maybe_show_account_assistant ();
-
-      create_salut_account_if_needed (managers);
-      g_object_unref (managers);
-      managers = NULL;
-      return TRUE;
-    }
-  return FALSE;
-}
-
-static void
-connection_managers_ready_cb (EmpathyConnectionManagers *managers,
-    GParamSpec *spec,
-    gpointer user_data)
-{
-  check_connection_managers_ready (managers);
+  tp_account_manager_prepare_async (account_mgr, NULL,
+      account_manager_ready_for_show_assistant, NULL);
 }
 
 static void
@@ -472,21 +336,47 @@ migrate_config_to_xdg_dir (void)
   g_free (old_dir);
 }
 
+static void
+connection_managers_prepare_for_accounts (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  EmpathyConnectionManagers *cm_mgr = EMPATHY_CONNECTION_MANAGERS (source);
+  GtkWidget *ui;
+
+  if (!empathy_connection_managers_prepare_finish (cm_mgr, result, NULL))
+    goto out;
+
+  ui = empathy_account_assistant_show (GTK_WINDOW (empathy_main_window_get ()),
+          cm_mgr);
+
+  if (account_dialog_only)
+    g_signal_connect (ui, "destroy", G_CALLBACK (gtk_main_quit), NULL);
+
+out:
+  g_object_unref (cm_mgr);
+}
+
 static void
 do_show_accounts_ui (GtkWindow *window,
     TpAccountManager *manager)
 {
-
-  GtkWidget *ui;
-
   if (has_non_salut_accounts (manager))
-    ui = empathy_accounts_dialog_show (window, NULL);
-  else
-    ui = empathy_account_assistant_show (window);
+    {
+      GtkWidget *ui;
 
-  if (account_dialog_only)
-    g_signal_connect (ui, "destroy",
-      G_CALLBACK (gtk_main_quit), NULL);
+      ui = empathy_accounts_dialog_show (window, NULL);
+
+      if (account_dialog_only)
+        g_signal_connect (ui, "destroy", G_CALLBACK (gtk_main_quit), NULL);
+    }
+  else
+    {
+      EmpathyConnectionManagers *cm_mgr;
+
+      empathy_connection_managers_prepare_async (cm_mgr,
+          connection_managers_prepare_for_accounts, NULL);
+    }
 }
 
 static void
@@ -671,22 +561,7 @@ account_manager_ready_cb (GObject *source_object,
       /* if current state is Offline, then put it online */
       empathy_idle_set_state (idle, TP_CONNECTION_PRESENCE_TYPE_AVAILABLE);
 
-  if (should_create_salut_account (manager)
-      || !empathy_import_mc4_has_imported ())
-    {
-      EmpathyConnectionManagers *managers;
-      managers = empathy_connection_managers_dup_singleton ();
-
-      if (!check_connection_managers_ready (managers))
-        {
-          g_signal_connect (managers, "notify::ready",
-            G_CALLBACK (connection_managers_ready_cb), NULL);
-        }
-    }
-  else if (!start_hidden)
-    {
-      maybe_show_account_assistant ();
-    }
+  maybe_show_account_assistant ();
 
   g_object_unref (idle);
   g_object_unref (connectivity);
@@ -709,12 +584,6 @@ setup_dispatcher (void)
     { TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER, TP_HANDLE_TYPE_CONTACT  },
     /* stream media to contacts */
     { TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA, TP_HANDLE_TYPE_CONTACT  },
-    /* stream tubes to contacts and rooms */
-    { TP_IFACE_CHANNEL_TYPE_STREAM_TUBE, TP_HANDLE_TYPE_CONTACT  },
-    { TP_IFACE_CHANNEL_TYPE_STREAM_TUBE, TP_HANDLE_TYPE_ROOM  },
-    /* d-bus tubes to contacts and rooms */
-    { TP_IFACE_CHANNEL_TYPE_DBUS_TUBE, TP_HANDLE_TYPE_CONTACT },
-    { TP_IFACE_CHANNEL_TYPE_DBUS_TUBE, TP_HANDLE_TYPE_ROOM  },
     /* roomlists */
     { TP_IFACE_CHANNEL_TYPE_ROOM_LIST, TP_HANDLE_TYPE_NONE },
   };
@@ -913,6 +782,9 @@ main (int argc, char *argv[])
   optcontext = g_option_context_new (N_("- Empathy IM Client"));
   g_option_context_add_group (optcontext, gst_init_get_option_group ());
   g_option_context_add_group (optcontext, gtk_get_option_group (TRUE));
+#if HAVE_LIBCHAMPLAIN
+  g_option_context_add_group (optcontext, clutter_get_option_group ());
+#endif
   g_option_context_add_main_entries (optcontext, options, GETTEXT_PACKAGE);
 
   if (!g_option_context_parse (optcontext, &argc, &argv, &error)) {
@@ -928,10 +800,6 @@ main (int argc, char *argv[])
   g_set_application_name (_(PACKAGE_NAME));
   g_setenv ("PULSE_PROP_media.role", "phone", TRUE);
 
-#if HAVE_LIBCHAMPLAIN
-  gtk_clutter_init (&argc, &argv);
-#endif
-
   gtk_window_set_default_icon_name ("empathy");
   textdomain (GETTEXT_PACKAGE);
 
@@ -1066,6 +934,7 @@ main (int argc, char *argv[])
   g_object_unref (unique_app);
 
   notify_uninit ();
+  xmlCleanupParser ();
 
   return EXIT_SUCCESS;
 }
